summaryrefslogtreecommitdiff
path: root/src/wx/screens_panel.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2022-01-22 23:21:41 +0100
committerCarl Hetherington <cth@carlh.net>2022-03-09 17:04:02 +0100
commitf3bc2bad4657d660a07f9578b2cb1897b4e9d8c2 (patch)
tree7100c19ecd0e60a675694f2b1c3b0b73e8cecb0b /src/wx/screens_panel.h
parent2fd641547b5fb795fc17e98e47f489fa82e8ff42 (diff)
Use checkboxes to decide which screens KDMs will be made for (#1895).
Diffstat (limited to 'src/wx/screens_panel.h')
-rw-r--r--src/wx/screens_panel.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/src/wx/screens_panel.h b/src/wx/screens_panel.h
index 7703d69aa..d5c5144bd 100644
--- a/src/wx/screens_panel.h
+++ b/src/wx/screens_panel.h
@@ -23,7 +23,7 @@ DCPOMATIC_DISABLE_WARNINGS
#include <wx/wx.h>
DCPOMATIC_ENABLE_WARNINGS
#include <wx/srchctrl.h>
-#include <wx/treectrl.h>
+#include <wx/treelist.h>
#include <boost/signals2.hpp>
#include <list>
#include <map>
@@ -36,22 +36,22 @@ namespace dcpomatic {
class Cinema;
-/** Shim around wxTreeCtrl so we can use strcoll() to compare things */
-class TreeCtrl : public wxTreeCtrl
+/** Shim around wxTreeListCtrl so we can use strcoll() to compare things */
+class TreeListCtrl : public wxTreeListCtrl
{
public:
- wxDECLARE_DYNAMIC_CLASS (TreeCtrl);
+ wxDECLARE_DYNAMIC_CLASS (TreeListCtrl);
- TreeCtrl () {}
+ TreeListCtrl () {}
- TreeCtrl (wxWindow* parent)
- : wxTreeCtrl (parent, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxTR_HIDE_ROOT | wxTR_MULTIPLE | wxTR_HAS_BUTTONS | wxTR_LINES_AT_ROOT)
+ TreeListCtrl (wxWindow* parent)
+ : wxTreeListCtrl (parent, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxTL_MULTIPLE | wxTL_3STATE | wxTL_NO_HEADER)
{}
- virtual ~TreeCtrl () {}
+ virtual ~TreeListCtrl () {}
private:
- int OnCompareItems (wxTreeItemId const& a, wxTreeItemId const& b);
+ int OnCompareItems (wxTreeListItem const& a, wxTreeListItem const& b);
};
@@ -68,30 +68,30 @@ public:
private:
void add_cinemas ();
- boost::optional<wxTreeItemId> add_cinema (std::shared_ptr<Cinema>);
- boost::optional<wxTreeItemId> add_screen (std::shared_ptr<Cinema>, std::shared_ptr<dcpomatic::Screen>);
+ boost::optional<wxTreeListItem> add_cinema (std::shared_ptr<Cinema>);
+ boost::optional<wxTreeListItem> add_screen (std::shared_ptr<Cinema>, std::shared_ptr<dcpomatic::Screen>);
void add_cinema_clicked ();
void edit_cinema_clicked ();
void remove_cinema_clicked ();
void add_screen_clicked ();
void edit_screen_clicked ();
void remove_screen_clicked ();
- void selection_changed_shim (wxTreeEvent &);
+ void selection_changed_shim (wxTreeListEvent &);
void selection_changed ();
void search_changed ();
+ void checkbox_changed (wxTreeListEvent& ev);
wxSearchCtrl* _search;
- TreeCtrl* _targets;
+ TreeListCtrl* _targets;
wxButton* _add_cinema;
wxButton* _edit_cinema;
wxButton* _remove_cinema;
wxButton* _add_screen;
wxButton* _edit_screen;
wxButton* _remove_screen;
- wxTreeItemId _root;
- typedef std::map<wxTreeItemId, std::shared_ptr<Cinema>> CinemaMap;
- typedef std::map<wxTreeItemId, std::shared_ptr<dcpomatic::Screen>> ScreenMap;
+ typedef std::map<wxTreeListItem, std::shared_ptr<Cinema>> CinemaMap;
+ typedef std::map<wxTreeListItem, std::shared_ptr<dcpomatic::Screen>> ScreenMap;
CinemaMap _cinemas;
ScreenMap _screens;